@@ -16,7 +16,6 @@ wallPaeper::wallPaeper(QWidget *parent) :
     ui->newBtn->setStyleSheet("text-align: left");
     ui->manBtn->setStyleSheet("text-align: left");
 
-    abtDialogExists = false;
     setupWPMenuBar();
 
     connect(ui->newBtn, SIGNAL(clicked()),
@@ -110,18 +109,15 @@ void wallPaeper::setupWPMenuBar() {
 
 
 void wallPaeper::createAbtDialog() {
-    // Only create a new dialog if it hasn't been made yet
-    if(abtDialogExists == false) {
-        abtDialog = new aboutDialog(this);
-        abtDialog->setWindowTitle("Wallpaeper 0.5 for Nokia N900");
+    // Create a new About dialog
+    abtDialog = new aboutDialog(this);
 
-        abtDialog->ui->aboutText1->adjustSize();
-        abtDialog->ui->aboutText2->adjustSize();
+    abtDialog->ui->aboutText1->adjustSize();
+    abtDialog->ui->aboutText2->adjustSize();
 
-        connect(abtDialog->ui->aboutBtnBox, SIGNAL(accepted()),
-                this->abtDialog, SLOT(close()));
+    connect(abtDialog->ui->aboutBtnBox, SIGNAL(accepted()),
+            this->abtDialog, SLOT(close()));
 
-        abtDialog->adjustSize();
-    }
+    abtDialog->adjustSize();
     abtDialog->show();
 }
