@@ -9,7 +9,6 @@
 #include "ui_aboutdialog.h"
 
 #include <QMainWindow>
-#include <QDialog>
 
 namespace Ui {
     class wallPaeper;
@@ -30,8 +29,7 @@ private:
     // The menu and its actions
     QMenu* wpMenu;
     QAction* wpMenuActionAbout;
-    // The About dialog with its contents
-    bool abtDialogExists;
+
     aboutDialog* abtDialog;
 
     wpNew* newWin;
